==> xld-codepipeline-plugin-1.0.0-sources.jar: com/xebialabs/deployit/plugin/codepipeline/actions/CreateTaskAction.java <==
package com.xebialabs.deployit.plugin.codepipeline.actions;

import com.amazonaws.service.codepipeline.model.Job;
import com.xebialabs.deployit.engine.api.dto.Deployment;
import com.xebialabs.deployit.plugin.codepipeline.exceptions.CodePipelinePluginExecutionException;
import com.xebialabs.deployit.plugin.codepipeline.helpers.Constants;
import com.xebialabs.deployit.plugin.codepipeline.helpers.XldConfig;
import com.xebialabs.deployit.plugin.codepipeline.services.CodePipelineJobService;
import com.xebialabs.deployit.plugin.codepipeline.services.XLDeployService;

import java.util.Map;

public class CreateTaskAction extends Action<String> {

    private final CodePipelineJobService jobService;
    private final XLDeployService xlDeployService;
    private final Job job;
    private final Deployment deployment;

    public CreateTaskAction(CodePipelineJobService jobService, XLDeployService xlDeployService, Job job, Deployment deployment) {
        this.jobService = jobService;
        this.xlDeployService = xlDeployService;
        this.job = job;
        this.deployment = deployment;
    }

    @Override
    public String execute() {
        return createTask(job, deployment);
    }

    @Override
    public String actionName() {
        return "Create Task";
    }

    private String createTask(Job job, Deployment deployment) {
        Map<String, String> jobData = jobService.getJobData(job);
        String taskId = xlDeployService.createTask(deployment, getXldConfig(jobData));

        if (taskId == null)
            throw new CodePipelinePluginExecutionException("Unable to create XL Deploy task");

        return taskId;
    }


    private XldConfig getXldConfig(Map<String, String> jobData) {
        String xldServerUrl = jobData.get(Constants.XL_DEPLOY_URL);
        String xldUsername = jobData.get(Constants.XL_DEPLOY_USERNAME);
        String xldPassword = jobData.get(Constants.XL_DEPLOY_PASSWORD);
        return new XldConfig(xldServerUrl, xldUsername, xldPassword);
    }
}

==> xld-codepipeline-plugin-1.0.1-sources.jar: com/xebialabs/deployit/plugin/codepipeline/actions/CreateTaskAction.java <==
package com.xebialabs.deployit.plugin.codepipeline.actions;

import com.amazonaws.services.codepipeline.model.Job;
import com.xebialabs.deployit.engine.api.dto.Deployment;
import com.xebialabs.deployit.plugin.codepipeline.exceptions.CodePipelinePluginExecutionException;
import com.xebialabs.deployit.plugin.codepipeline.helpers.Constants;
import com.xebialabs.deployit.plugin.codepipeline.helpers.XldConfig;
import com.xebialabs.deployit.plugin.codepipeline.services.CodePipelineJobService;
import com.xebialabs.deployit.plugin.codepipeline.services.XLDeployService;

import java.util.Map;

public class CreateTaskAction extends Action<String> {

    private final CodePipelineJobService jobService;
    private final XLDeployService xlDeployService;
    private final Job job;
    private final Deployment deployment;

    public CreateTaskAction(CodePipelineJobService jobService, XLDeployService xlDeployService, Job job, Deployment deployment) {
        this.jobService = jobService;
        this.xlDeployService = xlDeployService;
        this.job = job;
        this.deployment = deployment;
    }

    @Override
    public String execute() {
        return createTask(job, deployment);
    }

    @Override
    public String actionName() {
        return "Create Task";
    }

    private String createTask(Job job, Deployment deployment) {
        Map<String, String> jobData = jobService.getJobData(job);
        String taskId = xlDeployService.createTask(deployment, getXldConfig(jobData));

        if (taskId == null)
            throw new CodePipelinePluginExecutionException("Unable to create XL Deploy task");

        return taskId;
    }


    private XldConfig getXldConfig(Map<String, String> jobData) {
        String xldServerUrl = jobData.get(Constants.XL_DEPLOY_URL);
        String xldUsername = jobData.get(Constants.XL_DEPLOY_USERNAME);
        String xldPassword = jobData.get(Constants.XL_DEPLOY_PASSWORD);
        return new XldConfig(xldServerUrl, xldUsername, xldPassword);
    }
}
